@@ -38,10 +38,22 @@ from qgis.core import (
     QgsGeometry,
     QgsProject,
     QgsVectorLayer,
+    QgsMemoryProviderUtils,
+    QgsWkbTypes,
+    QgsVectorDataProvider,
+    QgsFields,
+    QgsField,
+)
+from qgis.server import (
+    QgsServerRequest,
+    QgsServer,
+    QgsBufferServerResponse,
+    QgsBufferServerRequest,
 )
-from qgis.server import QgsServerRequest
 from qgis.testing import unittest
 from test_qgsserver import QgsServerTestBase
+from qgis.PyQt.QtCore import QVariant, QUrl
+from test_qgsserver_accesscontrol import XML_NS
 
 # Strip path and content length because path may vary
 RE_STRIP_UNCHECKABLE = rb'MAP=[^"]+|Content-Length: \d+|timeStamp="[^"]+"'
@@ -330,7 +342,7 @@ class TestQgsServerWFS(QgsServerTestBase):
         project = self.testdata_path + "test_project_wfs.qgs"
         assert os.path.exists(project), "Project file not found: " + project
 
-        query_string = f"?MAP={urllib.parse.quote(project)}"
+        query_string = f"?SERVICE=WFS&MAP={urllib.parse.quote(project)}"
         header, body = self._execute_request(
             query_string,
             requestMethod=QgsServerRequest.PostMethod,
@@ -386,7 +398,7 @@ class TestQgsServerWFS(QgsServerTestBase):
                 )
             )
 
-        srsTemplate = """<?xml version="" encoding="UTF-8"?>
+        srsTemplate = """<?xml version="1.0" encoding="UTF-8"?>
 <wfs:GetFeature service="WFS" version="{}" {} xmlns:wfs="http://www.opengis.net/wfs" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://www.opengis.net/wfs http://schemas.opengis.net/wfs/1.1.0/wfs.xsd">
   <wfs:Query typeName="testlayer" {} xmlns:feature="http://www.qgis.org/gml">
     <ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">
@@ -520,7 +532,7 @@ class TestQgsServerWFS(QgsServerTestBase):
         </gml:Envelope>
       </ogc:BBOX>
     </ogc:Filter>
-    <ogc:SortBy>
+    <ogc:SortBy xmlns:ogc="http://www.opengis.net/ogc">
       <ogc:SortProperty>
         <ogc:PropertyName>id</ogc:PropertyName>
         <ogc:SortOrder>DESC</ogc:SortOrder>
@@ -956,6 +968,7 @@ class TestQgsServerWFS(QgsServerTestBase):
 
         post_data = """<?xml version="1.0" ?>
 <wfs:Transaction service="WFS" version="{version}"
+  xmlns:fes="http://www.opengis.org/fes"
   xmlns:ogc="http://www.opengis.net/ogc"
   xmlns:wfs="http://www.opengis.net/wfs"
   xmlns:gml="http://www.opengis.net/gml">
@@ -1010,9 +1023,10 @@ class TestQgsServerWFS(QgsServerTestBase):
                 "ogr",
             )
             self.assertTrue(vl.isValid())
-            self.assertEqual(
-                str(vl.getFeature(22)[field]), value if value is not None else "NULL"
-            )
+            if value is None:
+                self.assertTrue(str(vl.getFeature(22)[field]) in ["NULL", "None"])
+            else:
+                self.assertEqual(str(vl.getFeature(22)[field]), str(value))
 
         for version in ("1.0.0", "1.1.0"):
             _round_trip("0", "id_long", version)
@@ -1530,6 +1544,70 @@ class TestQgsServerWFS(QgsServerTestBase):
             project_file=project_file,
         )
 
+    def test_wfs_aspatial_getcapabilities(self):
+        ### Test issue GH #60185 - WFS GetCapabilities for aspatial layers"""
+
+        # create a memory layer with no geometry
+        fields = QgsFields()
+        fields.append(QgsField("id", QVariant.Int))
+        fields.append(QgsField("name", QVariant.String))
+        layer = QgsMemoryProviderUtils.createMemoryLayer(
+            "no_geom", fields, QgsWkbTypes.NoGeometry
+        )
+
+        provider = layer.dataProvider()
+        self.assertTrue(layer.isValid())
+        self.assertFalse(layer.isSpatial())
+        self.assertFalse(
+            provider.capabilities() & QgsVectorDataProvider.Capability.ChangeGeometries
+        )
+
+        project = QgsProject()
+        project.addMapLayer(layer)
+        project.writeEntry("WFSLayers", "/", [layer.id()])
+        project.writeEntry("WFSTLayers", "Update", [layer.id()])
+        project.writeEntry("WFSTLayers", "Insert", [layer.id()])
+        project.writeEntry("WFSTLayers", "Delete", [layer.id()])
+
+        server = QgsServer()
+        request = QgsServerRequest()
+        request.setUrl(QUrl("?SERVICE=WFS&REQUEST=GetCapabilities"))
+        response = QgsBufferServerResponse()
+        server.handleRequest(request, response, project)
+        body = response.body().data().decode("utf8").replace("\n", "")
+        self.assertIn("<Operation>Update</Operation>", body)
+
+        # Test an actual transaction
+        post_data = f"""<?xml version="1.0" encoding="UTF-8"?>
+<wfs:Transaction {XML_NS}>
+  <wfs:Insert idgen="GenerateNew">
+    <qgs:no_geom xmlns:qgs="http://www.qgis.org/gml">
+      <qgs:id>1</qgs:id>
+      <qgs:name>one</qgs:name>
+    </qgs:no_geom>
+  </wfs:Insert>
+</wfs:Transaction>"""
+
+        query_string = "?SERVICE=WFS&REQUEST=TRANSACTION"
+        request = QgsBufferServerRequest(
+            QUrl(query_string),
+            QgsServerRequest.PostMethod,
+            {},
+            post_data.encode("utf-8"),
+        )
+        response = QgsBufferServerResponse()
+        server.handleRequest(request, response, project)
+        body = response.body().data()
+
+        self.assertIn(b"<SUCCESS/>", body)
+
+        # Check the backend
+        features = list(provider.getFeatures())
+        self.assertEqual(len(features), 1)
+        f = features[0]
+        self.assertEqual(f["id"], 1)
+        self.assertEqual(f["name"], "one")
+
 
 if __name__ == "__main__":
     unittest.main()
